@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : albumdb.cpp
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2004-06-18
  * Description : 
@@ -8,7 +7,7 @@
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -258,9 +257,11 @@ void AlbumDB::readPAlbum(PAlbum *album)
     }
 
     kdDebug() << "Album not in database : " << album->getURL() << endl;
-    
-    /* Album not in database. first check if it is an album which was in
-       database, but has been copied/moved/renamed */
+
+    // Turn of automatic renaming as it can create havoc if user changes locale
+    /* 
+    //  Album not in database. first check if it is an album which was in
+    //  database, but has been copied/moved/renamed 
 
     int id;
     if (readIdentifier(album, id) && checkAlbum(album, id))
@@ -269,10 +270,12 @@ void AlbumDB::readPAlbum(PAlbum *album)
                   << album->getURL() << endl;
         return;
     }
+    */
+    
+    // Smells like an entirely new album. go ahead and 
+    // and add to database 
 
-    /* Smells like an entirely new album. go ahead and 
-       and add to database */
-
+    
     execSql( QString("INSERT INTO Albums (url, date, caption, collection) "
                      "VALUES('%1', '%2', '%3', '%4');")
              .arg(escapeString(album->getURL()))
@@ -280,15 +283,18 @@ void AlbumDB::readPAlbum(PAlbum *album)
              .arg(escapeString(album->getCaption()))
              .arg(escapeString(album->getCollection())) );
 
-    /* Write the identifier of the album into the directory */
+    // Write the identifier of the album into the directory 
 
-    id = sqlite_last_insert_rowid(m_db);
-    writeIdentifier(album, id);
+    int id = sqlite_last_insert_rowid(m_db);
     album->setID(id);
-    
-    /* try importing any old digikam.xml file */
 
+    // Turn of automatic renaming as it can create havoc if user changes locale
+    /* writeIdentifier(album, id); */
+
+    
+    // try importing any old digikam.xml file 
     importXML(album);
+    
 }
 
 void AlbumDB::readTAlbum(TAlbum* album)
@@ -972,6 +978,17 @@ void AlbumDB::moveTAlbum(TAlbum *album, TAlbum *parent)
              .arg(album->getID()) );
 }
 
+bool AlbumDB::addPAlbum(const QString& url, const QString& caption,
+                        const QDate& date, const QString& collection)
+{
+    return execSql( QString("REPLACE INTO Albums (url, date, caption, collection) "
+                            "VALUES('%1', '%2', '%3', '%4');")
+                    .arg(escapeString(url))
+                    .arg(date.toString(Qt::ISODate))
+                    .arg(escapeString(caption))
+                    .arg(escapeString(collection)));
+}
+
 bool AlbumDB::createTAlbum(TAlbum* parent, const QString& name,
                            const QString& icon)
 {
