@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : albumdb.h
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2004-06-18
  * Description : 
@@ -8,7 +7,7 @@
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -48,6 +47,8 @@ public:
     void renameAlbum(Album *album, const QString& newName);
     bool createTAlbum(TAlbum* parent, const QString& name, const QString& icon);
     void moveTAlbum(TAlbum *album, TAlbum *parent);
+    bool addPAlbum(const QString& url, const QString& caption,
+                   const QDate& date, const QString& collection);
     
     void beginTransaction();
     void commitTransaction();
