@@ -56,13 +56,12 @@
 #include <kaction.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
+#include <kglobalsettings.h>
+#include <kcursor.h>
 
 #include <kdeversion.h>
 #if KDE_IS_VERSION(3,2,0)
-#include <kinputdialog.h>
 #include <kcalendarsystem.h>
-#else
-#include <klineeditdlg.h>
 #endif
 
 // Local includes.
@@ -97,7 +96,8 @@ AlbumFolderView::AlbumFolderView(QWidget *parent)
 {
     setAcceptDrops(true);
     viewport()->setAcceptDrops(true);
-
+    viewport()->setMouseTracking(true);
+    
     dropTarget_     = 0;
     albumSortOrder_ = (int) AlbumSettings::ByFolder;
     groupItems_.setAutoDelete(false);
@@ -321,7 +321,7 @@ AlbumFolderItem* AlbumFolderView::findParentByCollection(PAlbum* album)
     QStringList collectionList = settings->getAlbumCollectionNames();
     QString collection = album->getCollection();
 
-    if (!collectionList.contains(collection))
+    if (collection.isEmpty() || !collectionList.contains(collection))
         collection = i18n("Uncategorized Albums");
 
     AlbumFolderItem* parentItem = 0;
@@ -544,6 +544,9 @@ void AlbumFolderView::slotAllAlbumsLoaded()
 
     setSelected(folderItem);
     ensureItemVisible(folderItem);
+
+    disconnect(albumMan_, SIGNAL(signalAllAlbumsLoaded()),
+               this, SLOT(slotAllAlbumsLoaded()));
 }
 
 void AlbumFolderView::albumNew()
@@ -583,31 +586,32 @@ void AlbumFolderView::albumNew(PAlbum* parent)
     {
         KMessageBox::error(0,
                            i18n("The Albums Library has not been set correctly.\n"
-                                "Select \"Configure Digikam\" from the Settings menu and choose a folder to use for the Albums Library."));
+                                "Select \"Configure Digikam\" from the Settings "
+                                "menu and choose a folder to use for the Albums "
+                                "Library."));
         return;
     }
 
-    bool ok;
-
-#if KDE_IS_VERSION(3,2,0)
-    QString newDir = KInputDialog::getText(i18n("New Album Name"),
-                                           i18n("<qt><b>Creating a new album in <i>%1</i></b><hr><br>\n"
-                                                   "Enter a name for the new album:</qt>")
-                                               .arg(parent->getPrettyURL()),
-                                           QString::null, &ok, this);
-#else
-    QString newDir = KLineEditDlg::getText(i18n("New Album Name"),
-                                           i18n("<qt><b>Creating a new album in <i>%1</i></b><hr><br>\n"
-                                                   "Enter a name for the new album:</qt>")
-                                                .arg(parent->getPrettyURL()),
-                                           QString::null, &ok, this);
-#endif
-
-    if (!ok)
+    QString     title;
+    QString     comments;
+    QString     collection;
+    QDate       date;
+    QStringList albumCollections;
+        
+    if (!AlbumPropsEdit::createNew(parent, title, comments, date, collection,
+                                   albumCollections))
         return;
 
+    QStringList oldAlbumCollections(AlbumSettings::instance()->getAlbumCollectionNames());
+    if (albumCollections != oldAlbumCollections)
+    {
+        AlbumSettings::instance()->setAlbumCollectionNames(albumCollections);
+        resort();
+    }
+    
     QString errMsg;
-    if (albumMan_->createPAlbum(parent, newDir, errMsg))
+    if (albumMan_->createPAlbum(parent, title, comments, date,
+                                collection, errMsg))
     {
         connect(albumMan_, SIGNAL(signalAlbumAdded(Album*)),
                 this, SLOT(slotNewAlbumCreated(Album*)));
@@ -628,15 +632,13 @@ void AlbumFolderView::slotNewAlbumCreated(Album* album)
         album->type() != Album::PHYSICAL) {
         return;
     }
-
+    
     PAlbum* pa = dynamic_cast<PAlbum*>(album);
     AlbumFolderItem* folderItem =
-        static_cast<AlbumFolderItem*>(pa->getViewItem());
-
+         static_cast<AlbumFolderItem*>(pa->getViewItem());
+    
     ensureItemVisible(folderItem);
     setSelected(folderItem);
-
-    albumEdit(pa);
 }
 
 void AlbumFolderView::albumDelete()
@@ -789,9 +791,9 @@ void AlbumFolderView::albumHighlight(PAlbum* album)
     {
         if (iconThumbJob_.isNull())
         {
-            iconThumbJob_ = new Digikam::ThumbnailJob(album->getIconKURL(),
-                                                (int)ThumbnailSize::Tiny,
-                                                false);
+            iconThumbJob_ = new ThumbnailJob(album->getIconKURL(),
+                                             (int)ThumbnailSize::Tiny,
+                                             true);
             connect(iconThumbJob_,
                     SIGNAL(signalThumbnailMetaInfo(const KURL&,
                                                 const QPixmap&,
@@ -836,7 +838,7 @@ void AlbumFolderView::slotGotThumbnailFromIcon(const KURL& url,
     folderItem->setPixmap(thumbnail);
 }
 
-void::AlbumFolderView::slotThumbnailLost(const KURL &url, bool isDir)
+void AlbumFolderView::slotThumbnailLost(const KURL &url, bool isDir)
 {
     if(isDir)
         return;
@@ -869,7 +871,9 @@ void AlbumFolderView::albumImportFolder()
     {
         KMessageBox::error(0,
                            i18n("The Albums Library has not been set correctly.\n"
-                                "Select \"Configure Digikam\" from the Settings menu and choose a folder to use for the Albums Library."));
+                                "Select \"Configure Digikam\" from the Settings "
+				"menu and choose a folder to use for the Albums "
+				"Library."));
         return;
     }
 
@@ -1066,6 +1070,9 @@ void AlbumFolderView::slotSelectionChanged(ListItem* item)
     if (folderItem->album_)
     {
         albumMan_->setCurrentAlbum(folderItem->album_);
+        stateAlbumSel_ = folderItem->album_->getID();
+        stateAlbumSel_ += (folderItem->album_->type() ==
+                           Album::PHYSICAL) ? 100000 : 200000;
     }
 }
 
@@ -1276,10 +1283,22 @@ void AlbumFolderView::contentsMousePressEvent(QMouseEvent *e)
 
 void AlbumFolderView::contentsMouseMoveEvent(QMouseEvent *e)
 {
-    if( !e ) return;
+    if ( !e ) return;
 
-    if( e->state() == NoButton )
+    ListItem* item = itemAt(e->pos());
+
+    if ( e->state() == NoButton )
+    {
+        if (KGlobalSettings::changeCursorOverIcon())
+        {
+            if (item)
+                setCursor(KCursor::handCursor());
+            else
+                unsetCursor();
+        }
+        dragItem_ = 0;
         return;
+    }
 
     // Dragging ?
     if( dragItem_ )
@@ -1293,6 +1312,16 @@ void AlbumFolderView::contentsMouseMoveEvent(QMouseEvent *e)
     }
 }
 
+void AlbumFolderView::contentsMouseReleaseEvent(QMouseEvent *)
+{
+    //dragItem_ = 0;
+}
+
+void AlbumFolderView::leaveEvent(QEvent*)
+{
+    //dragItem_ = 0;    
+}
+
 void AlbumFolderView::startDrag()
 {
     AlbumFolderItem *folderItem
@@ -1588,7 +1617,7 @@ void AlbumFolderView::phyAlbumDropEvent(QDropEvent* event, PAlbum *album)
             {
                 QString errMsg;
                 AlbumManager::instance()->updatePAlbumIcon(destAlbum,
-                    urls.first().path(), true, errMsg);
+                    urls.first().filename(), true, errMsg);
             }
             return;
         }
