@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : albumpropsedit.h
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2003-03-09
  * Description :
@@ -8,7 +7,7 @@
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  *
@@ -43,9 +42,11 @@ class PAlbum;
 
 class AlbumPropsEdit : public KDialogBase
 {
+    Q_OBJECT
+    
 public:
 
-    AlbumPropsEdit(PAlbum* album);
+    AlbumPropsEdit(PAlbum* album, bool create=false);
     ~AlbumPropsEdit();
 
     QString     title() const;
@@ -61,6 +62,13 @@ public:
                           QString& collection,
                           QStringList& albumCollections);
 
+    static bool createNew(PAlbum *parent,
+                          QString& title,
+                          QString& comments,
+                          QDate& date,
+                          QString& collection,
+                          QStringList& albumCollections);
+    
 private:
 
     PAlbum         *album_;
@@ -73,6 +81,10 @@ private:
 
     QComboBox      *collectionCombo_;
     QCheckListItem *rootCollectionItem_;
+
+private slots:
+
+   void slotTitleChanged(const QString& newtitle);
 };
 
 #endif /* ALBUMPROPSEDIT_H */
