@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : cameralist.cpp
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2003-02-03
  * Description : 
@@ -8,7 +7,7 @@
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -24,6 +23,10 @@
 #include <qdom.h>
 #include <qtextstream.h>
 
+#include <kmessagebox.h>
+#include <klocale.h>
+
+#include "gpiface.h"
 #include "cameratype.h"
 #include "cameralist.h"
 
@@ -181,6 +184,46 @@ CameraType* CameraList::find(const QString& title)
     return 0;
 }
 
+CameraType* CameraList::autoDetect(bool& retry)
+{
+    retry = false;
+    
+    QString model, port;
+    if (GPIface::autoDetect(model, port) != 0)
+    {
+       retry = ( KMessageBox::warningYesNo(0,
+                                           i18n("Failed to auto-detect camera; "
+                                                "please make sure it is connected "
+                                                "properly and is turned on. "
+                                                "Would you like to try again?"))
+                 == KMessageBox::Yes );
+        return 0;
+    }
+
+    // check if the camera is already in the list
+    for (CameraType *ctype = d->clist.first(); ctype;
+         ctype = d->clist.next()) {
+        // we can get away with checking only the model, as the auto-detection
+        // works only for usb cameras. so the port is always usb:
+        if (ctype->model() == model)
+            return ctype;
+    }
+
+    // looks like a new camera
+    
+    // NOTE: libgphoto2 now (2.1.4+) expects port names to be
+    // something like "usb:001,012". but on linux these port numbers
+    // will change everytime camera is reconnected. gphoto port funcs
+    // also allow regexp match, so the safe bet is to just pass in
+    // "usb:" and cross your fingers that user doesn't have multiple cameras
+    // connected at the same time (whack them if they do).
+    port = "usb:";
+    CameraType* ctype = new CameraType(model, model, port, "/");
+    insert(ctype);
+
+    return ctype;
+}
+
 void CameraList::clear()
 {
     
