@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : tagcreatedlg.cpp
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2004-07-01
  * Description :
@@ -8,7 +7,7 @@
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  *
@@ -75,12 +74,15 @@ TagCreateDlg::TagCreateDlg(TAlbum* parent)
     iconTextLabel->setBuddy(m_iconButton);
     gl->addWidget(m_iconButton, 1, 1);
 
-    QSpacerItem* spacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
+    QSpacerItem* spacer = new QSpacerItem(0, 0, QSizePolicy::Minimum,
+                                          QSizePolicy::Expanding);
     gl->addItem(spacer, 2, 1);
 
     connect(m_iconButton, SIGNAL(clicked()),
             SLOT(slotIconChange()));
-
+    connect(m_titleEdit, SIGNAL(textChanged(const QString&)),
+            SLOT(slotTitleChanged(const QString&)));
+    
     // by default assign the icon of the parent (if not root)
     // to this new tag
     if (!parent->isRoot())
@@ -89,6 +91,7 @@ TagCreateDlg::TagCreateDlg(TAlbum* parent)
         m_iconButton->setIconSet(SyncJob::getTagThumbnail(m_icon, 20));
     }
 
+    enableButtonOK(!m_titleEdit->text().isEmpty());
     adjustSize();
 }
 
@@ -114,6 +117,12 @@ void TagCreateDlg::slotIconChange()
     m_iconButton->setIconSet(SyncJob::getTagThumbnail(m_icon, 20));
 }
 
+
+void TagCreateDlg::slotTitleChanged(const QString& newtitle)
+{
+    enableButtonOK(!newtitle.isEmpty());
+}
+
 bool TagCreateDlg::tagCreate(TAlbum* parent, QString& title,
                              QString& icon)
 {
@@ -136,7 +145,8 @@ TagEditDlg::TagEditDlg(TAlbum* album)
     QVBoxLayout *topLayout = new QVBoxLayout(plainPage(), 0, spacingHint());
 
     QLabel *topLabel = new QLabel(plainPage());
-    topLabel->setText( i18n("<qt><b><i>%1</i> Properties</b></qt>").arg(album->getPrettyURL()) );
+    topLabel->setText( i18n("<qt><b><i>%1</i> Properties</b></qt>")
+                       .arg(album->getPrettyURL()) );
     topLabel->setAlignment(Qt::AlignAuto | Qt::AlignVCenter | Qt::SingleLine);
     topLayout->addWidget(topLabel);
 
@@ -171,15 +181,19 @@ TagEditDlg::TagEditDlg(TAlbum* album)
     iconTextLabel->setBuddy(m_iconButton);
     gl->addWidget(m_iconButton, 1, 1);
 
-    QSpacerItem* spacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
+    QSpacerItem* spacer = new QSpacerItem(0, 0, QSizePolicy::Minimum,
+                                          QSizePolicy::Expanding);
     gl->addItem(spacer, 2, 1);
 
     connect(m_iconButton, SIGNAL(clicked()),
             SLOT(slotIconChange()));
+    connect(m_titleEdit, SIGNAL(textChanged(const QString&)),
+            SLOT(slotTitleChanged(const QString&)));
 
     m_icon = album->getIcon();
     m_iconButton->setIconSet(SyncJob::getTagThumbnail(m_icon, 20));
 
+    enableButtonOK(!m_titleEdit->text().isEmpty());
     adjustSize();
 }
 
@@ -208,6 +222,11 @@ void TagEditDlg::slotIconChange()
     m_iconButton->setIconSet(SyncJob::getTagThumbnail(m_icon, 20));
 }
 
+void TagEditDlg::slotTitleChanged(const QString& newtitle)
+{
+    enableButtonOK(!newtitle.isEmpty());
+}
+
 bool TagEditDlg::tagEdit(TAlbum* album, QString& title,
                          QString& icon)
 {
@@ -223,3 +242,4 @@ bool TagEditDlg::tagEdit(TAlbum* album, QString& title,
 
 
 #include "tagcreatedlg.moc"
+
