@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : digikamio.cpp
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2004-08-28
  * Description : 
@@ -8,7 +7,7 @@
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -26,6 +25,8 @@
 #include <klocale.h>
 #include <klargefile.h>
 #include <kglobal.h>
+#include <kstandarddirs.h>
+#include <kio/global.h>
 
 #include <qfile.h>
 #include <qfileinfo.h>
@@ -43,6 +44,7 @@ extern "C"
 #include <sys/types.h>
 #include <sys/time.h>
 #include <time.h>
+#include <utime.h>
 #include <errno.h>
 #include <sqlite.h>
 }
@@ -67,10 +69,15 @@ kio_digikamioProtocol::kio_digikamioProtocol(const QCString &pool_socket,
 
     m_libraryPath = QDir::cleanDirPath(m_libraryPath);
     
-    QString path = m_libraryPath + "/digikam.db";
+    QString dbPath = m_libraryPath + "/digikam.db";
+
+#ifdef NFS_HACK
+    dbPath = QDir::homeDirPath() + "/.kde/share/apps/digikam/"  +
+             KIO::encodeFileName(QDir::cleanDirPath(dbPath));
+#endif
     
     char *errMsg = 0;
-    m_db = sqlite_open(QFile::encodeName(path), 0, &errMsg);
+    m_db = sqlite_open(QFile::encodeName(dbPath), 0, &errMsg);
     if (m_db == 0)
     {
         error(KIO::ERR_UNKNOWN, i18n("Failed to open Digikam Database"));
@@ -363,9 +370,11 @@ void kio_digikamioProtocol::copyInternal(const KURL& src, const KURL& dest,
 
         QString tmpFile(destDirURL.path());
 
-        if (!copyFile(_src, tmpFile))
+        if (!copyFile(src.path(), tmpFile))
         {
             error(KIO::ERR_COULD_NOT_WRITE, dest.prettyURL());
+            kdWarning() << k_funcinfo << "Failed to copy file to temporary file. "
+                        << "src: " << _src << ", temp: " << tmpFile <<  endl;
             failed = true;
             return;
         }
@@ -377,6 +386,8 @@ void kio_digikamioProtocol::copyInternal(const KURL& src, const KURL& dest,
         {
             unlink( QFile::encodeName(tmpFile) );
             error(KIO::ERR_COULD_NOT_WRITE, dest.prettyURL());
+            kdWarning() << k_funcinfo << "Failed to rename temporary file to destination file: "
+                        << _dest <<  endl;
             failed = true;
         }
         else
@@ -401,6 +412,18 @@ void kio_digikamioProtocol::copyInternal(const KURL& src, const KURL& dest,
                      .arg(escapeString(dest.fileName()))
                      .arg(oldDirID)
                      .arg(escapeString(src.fileName())) );
+
+            // also set the filetime to that of the original file
+            struct utimbuf t;
+            t.actime  = buff_src.st_atime;
+            t.modtime = buff_src.st_mtime;
+
+            if ( ::utime( _dest.data(), &t ) != 0 )
+            {
+                kdWarning() << k_funcinfo
+                            << "Failed to set datetime of destination file "
+                            << "to that of of original file" << endl;
+            }
         }
 
         execSql( "COMMIT TRANSACTION;");
@@ -421,7 +444,7 @@ void kio_digikamioProtocol::copyInternal(const KURL& src, const KURL& dest,
 
         QString tmpFile(destDirURL.path());
 
-        if (!copyFile(_src, tmpFile))
+        if (!copyFile(src.path(), tmpFile))
         {
             error(KIO::ERR_COULD_NOT_WRITE, dest.prettyURL());
             failed = true;
@@ -436,6 +459,18 @@ void kio_digikamioProtocol::copyInternal(const KURL& src, const KURL& dest,
             failed = true;
             return;
         }
+
+        // also set the filetime to that of the original file
+        struct utimbuf t;
+        t.actime  = buff_src.st_atime;
+        t.modtime = buff_src.st_mtime;
+
+        if ( ::utime( _dest.data(), &t ) != 0 )
+        {
+            kdWarning() << k_funcinfo
+                        << "Failed to set datetime of destination file "
+                        << "to that of of original file" << endl;
+        }
     }
 }
 
@@ -870,11 +905,17 @@ bool kio_digikamioProtocol::copyFile(const QString& src, const QString& dest)
     QFile dFile(dest);
 
     if ( !sFile.open(IO_ReadOnly) )
+    {
+        kdWarning() << k_funcinfo << "Failed to open source file for reading: "
+                    << src << endl;
         return false;
+    }
     
     if ( !dFile.open(IO_WriteOnly) )
     {
         sFile.close();
+        kdWarning() << k_funcinfo << "Failed to open dest file for writing: "
+                    << src << endl;
         return false;
     }
 
