@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imagehistogram.cpp
  * Author: Gilles Caulier <caulier dot gilles at free.fr>
  * Date  : 2004-07-21
  * Description : image histogram manipulation methods.
  * 
- * Copyright 2004 by Gilles Caulier
+ * Copyright 2004-2005 by Gilles Caulier
  *
  * Some code parts are inspired from gimp 2.0
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
@@ -21,15 +20,21 @@
  * GNU General Public License for more details.
  * 
  * ============================================================ */
- 
+  
 // C++ includes. 
  
 #include <cstdio>
 #include <cmath>
 #include <cstring>
 
+// Qt includes.
+
+#include <qobject.h>
+#include <qevent.h>
+
 // KDE includes.
 
+#include <kapplication.h>
 #include <kdebug.h>
 
 // Local includes.
@@ -39,72 +44,124 @@
 namespace Digikam
 {
 
-ImageHistogram::ImageHistogram(uint *i_data, uint i_w, uint i_h)
+ImageHistogram::ImageHistogram(uint *i_data, uint i_w, uint i_h, QObject *parent)
+              : QThread()
 { 
     m_imageData   = i_data;
     m_imageWidth  = i_w;
     m_imageHeight = i_h;    
-    calcHistogramValues();
+    m_parent      = parent;
+    m_histogram   = 0L;
+    m_runningFlag = true;   
+    
+    if (m_imageData && m_imageWidth && m_imageHeight)
+       {
+       if (m_parent)
+          start();
+       else
+          calcHistogramValues();
+       }
+    else
+       {
+       if (m_parent)
+          {
+          ImageHistogram::EventData *d = new ImageHistogram::EventData;
+          d->starting = false;
+          d->success = false;
+          QApplication::postEvent(m_parent, new QCustomEvent(QEvent::User, d));
+          }
+       }
 }
 
 ImageHistogram::~ImageHistogram()
 { 
+    stopCalcHistogramValues();
+    
     if (m_histogram)
        delete [] m_histogram;
 }
 
+void ImageHistogram::stopCalcHistogramValues(void)
+{
+    m_runningFlag = false;  
+    wait();
+}
+
+// List of threaded operations.
+
+void ImageHistogram::run()
+{
+    calcHistogramValues();
+}
+
 // This method is inspired of Gimp2.0 
 // app/base/gimphistogram.c::gimp_histogram_calculate_sub_region 
 
-bool ImageHistogram::calcHistogramValues()
+void ImageHistogram::calcHistogramValues()
 {
-    register uint  x, y;                   
+    register uint  i;                   
     unsigned char  blue, green, red, alpha;
     int            max;
     unsigned int  *p;
+    ImageHistogram::EventData *d;
     
+    if (m_parent)
+       {
+       d = new ImageHistogram::EventData;
+       d->starting = true;
+       d->success = false;
+       QApplication::postEvent(m_parent, new QCustomEvent(QEvent::User, d));
+       }
+        
     m_histogram = new double_packet[256];
     
     if ( !m_histogram )
        {
        kdWarning() << ("HistogramWidget::calcHistogramValues: Unable to allocate memory!") << endl;
-       return false;
+    
+       if (m_parent)
+          {
+          d = new ImageHistogram::EventData;
+          d->starting = false;
+          d->success = false;
+          QApplication::postEvent(m_parent, new QCustomEvent(QEvent::User, d));
+          }
+           
+       return;
        }
     
     memset(m_histogram, 0, 256*sizeof(struct double_packet));
-    
+
     // Form histogram (RAW DATA32 ARGB extraction method).
-   
-    for (y = 0 ; y < m_imageHeight ; ++y)
+
+    for (i = 0 ; (i < m_imageHeight*m_imageWidth) && m_runningFlag ; ++i)
       {
-      p = m_imageData + (m_imageWidth * y);
+      p = m_imageData + i;
       
-      for (x = 0 ; x < m_imageWidth ; ++x)
-         {           
-         blue  = (unsigned char)(*p);
-         green = (unsigned char)(*p >> 8);
-         red   = (unsigned char)(*p >> 16);
-         alpha = (unsigned char)(*p >> 24);
+      blue  = (unsigned char)(*p);
+      green = (unsigned char)(*p >> 8);
+      red   = (unsigned char)(*p >> 16);
+      alpha = (unsigned char)(*p >> 24);
          
-         m_histogram[blue].blue++;
-         m_histogram[green].green++;
-         m_histogram[red].red++;
-         m_histogram[alpha].alpha++;    
+      m_histogram[blue].blue++;
+      m_histogram[green].green++;
+      m_histogram[red].red++;
+      m_histogram[alpha].alpha++;    
          
-         max = (blue > green) ? blue : green;
+      max = (blue > green) ? blue : green;
          
-         if (red > max)
-            m_histogram[red].value++;
-         else
-            m_histogram[max].value++;
-
-         p++;
-         }
+      if (red > max) m_histogram[red].value++;
+      else m_histogram[max].value++;
       }
-    
-    return true;
-}
 
+    if (m_parent && m_runningFlag)
+       {
+       d = new ImageHistogram::EventData;
+       d->starting = false;
+       d->success = true;
+       QApplication::postEvent(m_parent, new QCustomEvent(QEvent::User, d));
+       }
+}
 
 double ImageHistogram::getCount(int channel, int start, int end)
 {
@@ -164,7 +221,7 @@ double ImageHistogram::getMean(int channel, int start, int end)
   double mean = 0.0;
   double count;
 
-  if ( !256 || start < 0 || 
+  if ( !m_histogram || start < 0 || 
        end > 256 || start > end )
        return 0.0;
 
