@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : cameraiconview.cpp
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2004-09-18
  * Description : 
@@ -8,7 +7,7 @@
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -40,29 +39,25 @@ extern "C"
 #include "renamecustomizer.h"
 
 CameraIconView::CameraIconView(CameraUI* ui, QWidget* parent)
-    : QIconView(parent), m_renamer(0), m_ui(ui)
+    : ThumbView(parent), m_renamer(0), m_ui(ui)
 {
-    setAutoArrange(true);    
-    setSorting(true);
-    setItemsMovable(false);
-    setResizeMode(Adjust);
-    setShowToolTips(false);
-    setSpacing(5);
-    setAcceptDrops(false);
-    setSelectionMode(Extended);
     setHScrollBarMode(QScrollView::AlwaysOff);
 
-    connect(this, SIGNAL(selectionChanged()),
+    CameraIconViewItem::m_newEmblem = new QPixmap(CameraIconViewItem::new_xpm);
+    
+    connect(this, SIGNAL(signalSelectionChanged()),
             SLOT(slotSelectionChanged()));
-    connect(this, SIGNAL(contextMenuRequested(QIconViewItem*, const QPoint&)),
-            SLOT(slotContextMenu(QIconViewItem*, const QPoint&)));
-    connect(this, SIGNAL(doubleClicked(QIconViewItem*)),
-            SLOT(slotDoubleClicked(QIconViewItem*)));
+    connect(this, SIGNAL(signalRightButtonClicked(ThumbItem*, const QPoint&)),
+            SLOT(slotContextMenu(ThumbItem*, const QPoint&)));
+    connect(this, SIGNAL(signalDoubleClicked(ThumbItem*)),
+            SLOT(slotDoubleClicked(ThumbItem*)));
 }
 
 CameraIconView::~CameraIconView()
 {
-    
+    clear();
+    delete CameraIconViewItem::m_newEmblem;
+    CameraIconViewItem::m_newEmblem = 0;
 }
 
 void CameraIconView::setRenameCustomizer(RenameCustomizer* renamer)
@@ -74,20 +69,19 @@ void CameraIconView::setRenameCustomizer(RenameCustomizer* renamer)
 
 void CameraIconView::addItem(const GPItemInfo& info)
 {
-    CameraIconViewItem* item = new CameraIconViewItem(this, info);
-    item->setDragEnabled(false);
-    m_itemDict.insert(info.folder+info.name, item);
-
-    if (m_renamer && !m_renamer->useDefault())
-    {
-        item->setDownloadName( getTemplatedName( m_renamer->nameTemplate(),
-                                                 item ) );
-    }
-
     KMimeType::Ptr mime;
     mime = KMimeType::mimeType( info.mime );
-    QPixmap p = mime->pixmap( KIcon::Desktop, 100, KIcon::DefaultState);
-    item->setPixmap(p);
+    QPixmap pix = mime->pixmap( KIcon::Desktop, 100, KIcon::DefaultState);
+
+    QString downloadName;
+    if (m_renamer && !m_renamer->useDefault())
+    {
+        downloadName = getTemplatedName( m_renamer->nameTemplate(), &info,
+                                         m_itemDict.count() );
+    }
+
+    CameraIconViewItem* item = new CameraIconViewItem(this, info, pix, downloadName);
+    m_itemDict.insert(info.folder+info.name, item);
 }
 
 void CameraIconView::removeItem(const QString& folder, const QString& file)
@@ -97,7 +91,12 @@ void CameraIconView::removeItem(const QString& folder, const QString& file)
         return;
 
     delete item;
-    arrangeItemsInGrid();
+    triggerUpdate();
+}
+
+CameraIconViewItem* CameraIconView::findItem(const QString& folder, const QString& file)
+{
+    return m_itemDict.find(folder+file);
 }
 
 void CameraIconView::setThumbnail(const QString& folder, const QString& filename,
@@ -108,6 +107,7 @@ void CameraIconView::setThumbnail(const QString& folder, const QString& filename
         return;
 
     item->setPixmap(pixmap);
+    item->repaint();
 }
 
 void CameraIconView::slotDownloadNameChanged()
@@ -122,41 +122,43 @@ void CameraIconView::slotDownloadNameChanged()
     }
     
     viewport()->setUpdatesEnabled(false);
-    for (QIconViewItem* item = firstItem(); item;
+    for (ThumbItem* item = firstItem(); item;
          item = item->nextItem())
     {
         CameraIconViewItem* viewItem =
             static_cast<CameraIconViewItem*>(item);
         viewItem->setDownloadName( useDefault ? QString::null :
-                                   getTemplatedName( nameTemplate, viewItem ) );
+                                   getTemplatedName( nameTemplate,
+                                                     viewItem->itemInfo(),
+                                                     index(viewItem) ) );
     }
-    arrangeItemsInGrid();
+    rearrangeItems();
     viewport()->setUpdatesEnabled(true);
     viewport()->update();
 }
 
 QString CameraIconView::getTemplatedName(const QString& templ,
-                                         CameraIconViewItem* item)
+                                         const GPItemInfo* itemInfo,
+                                         int position)
 {
     if (templ.isEmpty())
         return QString::null;
     
     QString dname(templ);
     
-    QString ext = item->text();
+    QString ext = itemInfo->name;
     int pos = ext.findRev('.');
     if (pos < 0)
         ext = "";
     else
         ext = ext.right( ext.length() - pos - 1);
 
-    struct tm* time_tm = gmtime(&item->m_itemInfo->mtime);
-    char* s = new char[100];
+    struct tm* time_tm = ::localtime(&itemInfo->mtime);
+    char s[100];
     strftime(s, 100, QFile::encodeName(dname), time_tm);
     dname  = s;
-    delete [] s;
 
-    dname.sprintf(QFile::encodeName(dname), index(item)+1);
+    dname.sprintf(QFile::encodeName(dname), position+1);
     dname.replace("/","");
 
     dname += '.';
@@ -169,7 +171,7 @@ void CameraIconView::slotSelectionChanged()
 {
     bool selected = false;
     
-    for (QIconViewItem* item = firstItem(); item;
+    for (ThumbItem* item = firstItem(); item;
          item = item->nextItem())
     {
         if (item->isSelected())
@@ -182,7 +184,7 @@ void CameraIconView::slotSelectionChanged()
     emit signalSelected(selected);
 }
 
-void CameraIconView::slotContextMenu(QIconViewItem * item, const QPoint&)
+void CameraIconView::slotContextMenu(ThumbItem * item, const QPoint&)
 {
     if (!item)
         return;
@@ -194,7 +196,7 @@ void CameraIconView::slotContextMenu(QIconViewItem * item, const QPoint&)
     CameraIconViewItem* camItem = static_cast<CameraIconViewItem*>(item);
     
     QPopupMenu menu;
-    menu.insertItem(SmallIcon("editimage"), i18n("View"), 0);
+    menu.insertItem(SmallIcon("editimage"), i18n("&View"), 0);
     menu.insertSeparator();
     menu.insertItem(i18n("Properties"), 1);
     menu.insertItem(SmallIcon("text_block"), i18n("EXIF Information"), 2);
@@ -236,7 +238,7 @@ void CameraIconView::slotContextMenu(QIconViewItem * item, const QPoint&)
     }
 }
 
-void CameraIconView::slotDoubleClicked(QIconViewItem* item)
+void CameraIconView::slotDoubleClicked(ThumbItem* item)
 {
     if (!item)
         return;
@@ -247,4 +249,37 @@ void CameraIconView::slotDoubleClicked(QIconViewItem* item)
     emit signalFileView(static_cast<CameraIconViewItem*>(item));
 }
 
+void CameraIconView::slotSelectAll()
+{
+    selectAll();    
+}
+
+void CameraIconView::slotSelectNone()
+{
+    clearSelection();
+}
+
+void CameraIconView::slotSelectInvert()
+{
+    invertSelection();
+}
+
+void CameraIconView::slotSelectNew()
+{
+    blockSignals(true);
+    clearSelection();
+    for (ThumbItem* item = firstItem(); item;
+         item = item->nextItem())
+    {
+        CameraIconViewItem* viewItem =
+            static_cast<CameraIconViewItem*>(item);
+        if (viewItem->itemInfo()->downloaded == 0)
+        {
+            viewItem->setSelected(true, false);
+        }
+    }
+    blockSignals(false);
+    emit signalSelectionChanged();
+}
+
 #include "cameraiconview.moc"
