@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : gpcamera.cpp
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2003-01-21
  * Description : 
@@ -8,7 +7,7 @@
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -85,6 +84,7 @@ bool GPStatus::cancel = false;
 GPCamera::GPCamera(const QString& model,
                    const QString& port,
                    const QString& path)
+    : DKCamera(model, port, path)
 {
     status = 0;
     
