@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : imageplugin.h
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2004-06-04
  * Description : 
@@ -8,7 +7,7 @@
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -23,24 +22,20 @@
 #define IMAGEPLUGIN_H
 
 #include <qobject.h>
+#include <kxmlguiclient.h>
 
-#include "guiclient.h"
-
-class KInstance;
 class QWidget;
 
 namespace Digikam
 {
 
-class ImagePlugin : public QObject, public GUIClient
+class ImagePlugin : public QObject, public KXMLGUIClient
 {
 public:
     
     ImagePlugin(QObject *parent, const char* name=0);
     virtual ~ImagePlugin();
 
-    void setInstance(KInstance *instance);
-
     virtual void setEnabledSelectionActions(bool enable);
 
     void     setParentWidget(QWidget* parent);
@@ -48,7 +43,6 @@ public:
     
 private:
 
-    KInstance  *m_instance;
     QWidget    *m_parentWidget;
 };
 
